package com.suning.snimagesearchsdk.util;

import java.io.ByteArrayInputStream;
import java.io.ByteArrayOutputStream;
import java.security.MessageDigest;
import java.security.NoSuchAlgorithmException;
import java.text.SimpleDateFormat;
import java.util.Date;

import android.content.Context;
import android.graphics.Bitmap;
import android.graphics.BitmapFactory;
import android.graphics.Canvas;
import android.graphics.ColorMatrix;
import android.graphics.ColorMatrixColorFilter;
import android.graphics.Paint;
import android.os.Build;
import android.telephony.TelephonyManager;

/**
 * 图像压缩工具类
 * @author 14100797
 *
 */
public class ImageUtils {


	public static Bitmap toGrayscale(Bitmap bmpOriginal) {
		//Bitmap bmpOriginal;
		int width, height;

		//bmpOriginal = compressImage(bmp);

		height = bmpOriginal.getHeight();
		width = bmpOriginal.getWidth();

		Bitmap bmpGrayscale = Bitmap.createBitmap(width, height, Bitmap.Config.RGB_565);
		Canvas c = new Canvas(bmpGrayscale);
		Paint paint = new Paint();
		ColorMatrix cm = new ColorMatrix();
		cm.setSaturation(0);
		ColorMatrixColorFilter f = new ColorMatrixColorFilter(cm);
		paint.setColorFilter(f);
		c.drawBitmap(bmpOriginal, 0, 0, paint);
		return bmpGrayscale;
	}

	/**
	 *
	 * 进行质量压缩,图片压缩到最小
	 * @param image
	 * @return
	 */
	private static Bitmap compressImage(Bitmap image) {

		ByteArrayOutputStream baos = new ByteArrayOutputStream();
		image.compress(Bitmap.CompressFormat.JPEG, 100, baos);//质量压缩方法，这里100表示不压缩，把压缩后的数据存放到baos中
		int options = 100;
		while ( baos.toByteArray().length / 1024>90) {	//循环判断如果压缩后图片是否大于100kb,大于继续压缩
			baos.reset();//重置baos即清空baos
			image.compress(Bitmap.CompressFormat.JPEG, options, baos);//这里压缩options%，把压缩后的数据存放到baos中
			options -= 10;//每次都减少10
		}
		ByteArrayInputStream isBm = new ByteArrayInputStream(baos.toByteArray());//把压缩后的数据baos存放到ByteArrayInputStream中
		Bitmap bitmap = BitmapFactory.decodeStream(isBm, null, null);//把ByteArrayInputStream数据生成图片
		return bitmap;
	}



	/**
	 * 压缩指定byte[]图片，并得到压缩后的图像
	 *
	 * @param bts
	 * @param reqsW
	 * @return
	 */
	public final static Bitmap compressBitmap(byte[] bts, int reqsW) {
		final BitmapFactory.Options options = new BitmapFactory.Options();
		options.inJustDecodeBounds = true;
		BitmapFactory.decodeByteArray(bts, 0, bts.length, options);

		int width = Math.min(options.outWidth, options.outHeight);
		int ratio = Math.round((float) width / (float) reqsW);
		options.inSampleSize = ratio;
		options.inJustDecodeBounds = false;
		return BitmapFactory.decodeByteArray(bts, 0, bts.length, options);
	}


	/**
    *
    * @param bm
    * @param isGray 是否灰度处理图像,true 灰度处理图片，fase 不灰度处理
    * @return
    */
   public static byte[] Bitmap2Bytes(Bitmap bm,boolean isGray) {
       Bitmap bit = null;
       if(isGray){
           bit = toGrayscale(bm);
       }else{
           bit = bm;
       }

       //compressImageToByte(bit);
       ByteArrayOutputStream baos = new ByteArrayOutputStream();
       bit.compress(Bitmap.CompressFormat.JPEG, 80, baos);
       System.out.println("--------------------imageutil---size---------------------------" + (baos.toByteArray().length / 1024));
       return baos.toByteArray();
       //return compressImageToByte(bit);
   }
	
	
//	public static String getImageBase64(Bitmap bitmap){
//		Bitmap grayBitmpa = toGrayscale(bitmap);
//		
//		byte[] grayByte = Bitmap2Bytes(grayBitmpa);
//		
//		String grayBaseStr = Base64.encodeToString(grayByte, Base64.NO_WRAP);
//		
//		return grayBaseStr;
//	} 
	
	public static String getImageBase64(byte[] grayByte){
		
		//String grayBaseStr = Base64.encodeToString(grayByte, Base64.NO_WRAP);
		String grayBaseStr = Base64.encode(grayByte);
		return grayBaseStr;
	} 
	
	
	public static String getByteMD5(byte[] dataByte) {  
	    byte[] hash;  
	  
	    try {
	        hash = MessageDigest.getInstance("MD5").digest(dataByte);  
	    } catch (NoSuchAlgorithmException e) {  
	        e.printStackTrace();  
	        return null;  
	    }  
	  
	    StringBuilder hex = new StringBuilder(hash.length * 2);  
	    for (byte b : hash) {  
	        if ((b & 0xFF) < 0x10)  
	            hex.append("0");  
	        hex.append(Integer.toHexString(b & 0xFF));  
	    }  
	  
	    return hex.toString();  
	}  
	
			
	public static String getPhoneModel(){
		Build bd = new Build();  
		String model = bd.MODEL;
		return model;
	}
	
	/**
	 * @param mContext
	 * @return
	 */
	public static String getPhoneImei(Context mContext){
		TelephonyManager telephonyManager= (TelephonyManager) mContext.getSystemService(Context.TELEPHONY_SERVICE);
		String imei=telephonyManager.getDeviceId();
		return imei;
	}
	
	static SimpleDateFormat format = new SimpleDateFormat("yyyy-MM-dd,HH:mm");  
	   
	/**
	 * 获取上传时间
	 * @return
	 */
    public static String getPicTime(){
    	 String time=format.format(new Date());
    	 return time;
    }

}
